@@ -36,13 +36,13 @@
             if (d === undefined) {
                 d = '';
             }
-            return Sao.PYSON.Get(this, k, d);
+            return new Sao.PYSON.Get(this, k, d);
         },
         in_: function(obj) {
-            return Sao.PYSON.In(this, obj);
+            return new Sao.PYSON.In(this, obj);
         },
         contains: function(k) {
-            return Sao.PYSON.In(k, this);
+            return new Sao.PYSON.In(k, this);
         },
         toString: function() {
             var klass = this.pyson().__class__;
@@ -201,7 +201,7 @@
                     value = new Sao.PYSON.Bool(value);
                     }
             } else if (typeof value != 'boolean') {
-                value = Sao.PYSON.Bool(value);
+                value = new Sao.PYSON.Bool(value);
             }
             this._value = value;
         },
@@ -220,7 +220,7 @@
     });
 
     Sao.PYSON.Not.eval_ = function(value, context) {
-        return !value.v;
+        return !Sao.PYSON.Bool.eval_(value, context);
     };
     Sao.PYSON.Not.init_from_object = function(obj) {
         return new Sao.PYSON.Not(obj.v);
