@@ -1,6 +1,9 @@
 /* This file is part of Tryton.  The COPYRIGHT file at the top level of
    this repository contains the full copyright notices and license terms. */
+
+/* eslint-disable no-redeclare */
 var Sao = {};
+/* eslint-enable no-redeclare */
 
 (function() {
     'use strict';
@@ -716,11 +719,14 @@ var Sao = {};
 
     Sao.main_menu_row_activate = function() {
         var screen = Sao.main_menu_screen;
-        // ids is not defined to prevent to add suffix
-        return Sao.Action.exec_keyword('tree_open', {
-            'model': screen.model_name,
-            'id': screen.get_id(),
-        }, null, false);
+        var id = screen.get_id();
+        if (id) {
+            // ids is not defined to prevent to add suffix
+            Sao.Action.exec_keyword('tree_open', {
+                'model': screen.model_name,
+                'id': screen.get_id(),
+            }, null, false);
+        }
     };
 
     Sao.menu = function(preferences) {
@@ -1102,7 +1108,7 @@ var Sao = {};
                     if (definition.id){
                         var current_tab = Sao.Tab.tabs.get_current();
                         if (current_tab) {
-                            var focused = $(':focus');
+                            var focused = jQuery(':focus');
                             focused.blur();
                             current_tab.el.find('a[id="' + definition.id + '"]').click();
                             focused.focus();
@@ -1174,7 +1180,7 @@ var Sao = {};
     .on('hidden.bs.modal', '.modal', function(event) {
         setModalsAndBackdropsOrder();
         if (jQuery('.modal:visible').length) {
-            $(document.body).addClass('modal-open');
+            jQuery(document.body).addClass('modal-open');
         }
     });
 
