@@ -153,7 +153,7 @@
                 }
             }.bind(this));
 
-            var readonly = this.screen.readonly || this.screen.group.readonly;
+            var readonly = this.screen.group.readonly;
 
             this._initial_value = null;
             if (view_type == 'form') {
@@ -346,7 +346,7 @@
             var name = '_';
             var access = Sao.common.MODELACCESS.get(this.screen.model_name);
             var deletable = this.screen.deletable;
-            var readonly = this.screen.readonly || this.screen.group.readonly;
+            var readonly = this.screen.group.readonly;
             if (data[0] >= 1) {
                 name = data[0];
                 if (this.domain) {
@@ -354,10 +354,12 @@
                 }
                 this.but_next.prop('disabled', data[0] >= data[1]);
                 this.but_previous.prop('disabled', data[0] <= 1);
-                if (access.delete && !readonly && deletable) {
-                    this.but_del.prop('disabled', false);
-                    this.but_undel.prop('disabled', false);
-                }
+                this.but_del.prop(
+                    'disabled',
+                    readonly ||
+                    !access.delete ||
+                    !deletable);
+                this.but_undel.prop('disabled', readonly);
             } else {
                 this.but_del.prop('disabled', true);
                 this.but_undel.prop('disabled', true);
@@ -423,7 +425,7 @@
         response: function(response_id) {
             var result;
             this.screen.current_view.set_value();
-            var readonly = this.screen.readonly || this.screen.group.readonly;
+            var readonly = this.screen.group.readonly;
             if (~['RESPONSE_OK', 'RESPONSE_ACCEPT'].indexOf(response_id) &&
                     !readonly &&
                     this.screen.current_record) {
@@ -770,7 +772,8 @@
             if (response_id == 'RESPONSE_OK') {
                 records = this.screen.current_view.selected_records;
             } else if (response_id == 'RESPONSE_APPLY') {
-                this.screen.search_filter();
+                this.screen.search_filter(
+                    this.screen.screen_container.get_text());
                 return;
             } else if (response_id == 'RESPONSE_ACCEPT') {
                 var view_ids = jQuery.extend([], this.view_ids);
